import { Component, Input, OnInit } from '@angular/core'
import { ActivatedRoute } from '@angular/router'
import { Location } from '@angular/common'

import { Mieter } from '../mieter'
import { ZahlungForderung } from '../zahlung-forderung'
import { Saldo } from '../saldo'

import { MieterService} from '../mieter.service'
import { ZahlungForderungService} from '../zahlung-forderung.service'
import { MessageService } from '../message.service'
import { MatTableDataSource } from '@angular/material/table'

@Component({
  selector: 'app-mieter-detail',
  templateUrl: './mieter-detail.component.html',
  styleUrls: ['./mieter-detail.component.css']
})
export class MieterDetailComponent implements OnInit {

  mieter: Mieter
  year: string
  zahlungenForderungen : ZahlungForderung[]
  saldo: Saldo

  displayedColumns: string[] = ["datum_soll", "datum_ist", "betrag_forderung", "betrag_zahlung", "kommentar"]
  dataSource: MatTableDataSource<ZahlungForderung>

  constructor(
    private mieterService: MieterService, 
    private zahlungForderungService: ZahlungForderungService,
    private messageService: MessageService,
    private route: ActivatedRoute,
    private location: Location ) { 
  }

  async getMieter(): Promise<void> {
    const id = +this.route.snapshot.paramMap.get('id')
    try {
      this.mieter = await this.mieterService.getMieter(id)
      await this.getZahlungenForderungen()
    } catch (err) {
      this.messageService.add(JSON.stringify(err, undefined, 4))
    }
  }

  async getZahlungenForderungen(): Promise<void> {
    const id = this.mieter?.id ?? 0
    try {
      this.zahlungenForderungen = await this.zahlungForderungService.getZahlungenForderungenByMieterAndYear(id, +this.year)
      this.saldo = await this.zahlungForderungService.getSaldoByMieterAndYear(id, +this.year)
    } catch (err) {
      this.messageService.add(JSON.stringify(err, undefined, 4))
    }
  }

  async onYearInput(): Promise<void> {
    await this.getZahlungenForderungen()
    this.dataSource = new MatTableDataSource<ZahlungForderung>(this.zahlungenForderungen)
  }

  async ngOnInit(): Promise<void> {
    this.year = new Date().getFullYear().toString()
    await this.getMieter()
    await this.getZahlungenForderungen()
  }
}
